==> haskell-edisoncore-1.3.3.2-5.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-edisoncore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 EdisonCore
version:              1.3.3.2
visibility:           public
id:                   EdisonCore-1.3.3.2-EdcNULi9cilHBivhEGy8Nv
key:                  EdisonCore-1.3.3.2-EdcNULi9cilHBivhEGy8Nv
license:              MIT
maintainer:           robdockins AT fastmail DOT fm
author:               Chris Okasaki
stability:            Stable
homepage:             https://github.com/robdockins/edison
synopsis:
    A library of efficient, purely-functional data structures (Core Implementations)

description:
    This package provides the core Edison data structure implementations,
    including multiple sequence, set, bag, and finite map concrete
    implementations with various performance characteristics. The
    implementations in this package have no dependencies other than those
    commonly bundled with Haskell compilers.

category:             Data Structures
abi:                  c795ff49538c5a77278f30fb4f566028
exposed:              True
exposed-modules:
    Data.Edison.Assoc.AssocList Data.Edison.Assoc.Defaults
    Data.Edison.Assoc.PatriciaLoMap Data.Edison.Assoc.StandardMap
    Data.Edison.Assoc.TernaryTrie Data.Edison.Coll.Defaults
    Data.Edison.Coll.EnumSet Data.Edison.Coll.LazyPairingHeap
    Data.Edison.Coll.LeftistHeap Data.Edison.Coll.MinHeap
    Data.Edison.Coll.SkewHeap Data.Edison.Coll.SplayHeap
    Data.Edison.Coll.StandardSet Data.Edison.Coll.UnbalancedSet
    Data.Edison.Concrete.FingerTree Data.Edison.Seq.BankersQueue
    Data.Edison.Seq.BinaryRandList Data.Edison.Seq.BraunSeq
    Data.Edison.Seq.Defaults Data.Edison.Seq.FingerSeq
    Data.Edison.Seq.JoinList Data.Edison.Seq.MyersStack
    Data.Edison.Seq.RandList Data.Edison.Seq.RevSeq
    Data.Edison.Seq.SimpleQueue Data.Edison.Seq.SizedSeq

import-dirs:          /usr/lib/ghc-9.4.8/site-local/EdisonCore-1.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/EdisonCore-1.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/EdisonCore-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-edisoncore
hs-libraries:         HSEdisonCore-1.3.3.2-EdcNULi9cilHBivhEGy8Nv
depends:
    EdisonAPI-1.3.3.1-GmhlvZKM41qE6hBohhdpjs
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O array-0.5.4.0
    base-4.17.2.1 containers-0.6.7

haddock-interfaces:   /usr/share/doc/haskell-edisoncore/html/EdisonCore.haddock
haddock-html:         /usr/share/doc/haskell-edisoncore/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edisoncore-1.3.3-40-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-edisoncore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 EdisonCore
version:              1.3.3
visibility:           public
id:                   EdisonCore-1.3.3-CYt457qAq41FCHj7yCwxUi
key:                  EdisonCore-1.3.3-CYt457qAq41FCHj7yCwxUi
license:              MIT
maintainer:           robdockins AT fastmail DOT fm
author:               Chris Okasaki
stability:            Stable
homepage:             http://rwd.rdockins.name/edison/home/
synopsis:
    A library of efficient, purely-functional data structures (Core Implementations)

description:
    This package provides the core Edison data structure implementations,
    including multiple sequence, set, bag, and finite map concrete
    implementations with various performance characteristics. The
    implementations in this package have no dependencies other than those
    commonly bundled with Haskell compilers.

category:             Data Structures
abi:                  72f1e223079cc7eaaee9df137d447047
exposed:              True
exposed-modules:
    Data.Edison.Assoc.AssocList Data.Edison.Assoc.Defaults
    Data.Edison.Assoc.PatriciaLoMap Data.Edison.Assoc.StandardMap
    Data.Edison.Assoc.TernaryTrie Data.Edison.Coll.Defaults
    Data.Edison.Coll.EnumSet Data.Edison.Coll.LazyPairingHeap
    Data.Edison.Coll.LeftistHeap Data.Edison.Coll.MinHeap
    Data.Edison.Coll.SkewHeap Data.Edison.Coll.SplayHeap
    Data.Edison.Coll.StandardSet Data.Edison.Coll.UnbalancedSet
    Data.Edison.Concrete.FingerTree Data.Edison.Seq.BankersQueue
    Data.Edison.Seq.BinaryRandList Data.Edison.Seq.BraunSeq
    Data.Edison.Seq.Defaults Data.Edison.Seq.FingerSeq
    Data.Edison.Seq.JoinList Data.Edison.Seq.MyersStack
    Data.Edison.Seq.RandList Data.Edison.Seq.RevSeq
    Data.Edison.Seq.SimpleQueue Data.Edison.Seq.SizedSeq

import-dirs:          /usr/lib/ghc-9.2.8/site-local/EdisonCore-1.3.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/EdisonCore-1.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-edisoncore
hs-libraries:         HSEdisonCore-1.3.3-CYt457qAq41FCHj7yCwxUi
depends:
    EdisonAPI-1.3.3-RJpFe7rX6zFO59KDO9B0t
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X array-0.5.4.0
    base-4.16.4.0 containers-0.6.5.1 mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-edisoncore/html/EdisonCore.haddock
haddock-html:         /usr/share/doc/haskell-edisoncore/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
